@@ -28,7 +28,7 @@
 //! Add vaultrs as a depdendency to your cargo.toml:
 //! ```ignore
 //! [dependencies]
-//! vaultrs = "0.3.0"
+//! vaultrs = "0.5.1"
 //! ```
 //!
 //! ## Usage
@@ -41,8 +41,7 @@
 //! communicating to Vault.
 //!
 //! ```rust
-//! use vaultrs::client::{VaultClient, VaultClientSettingsBuilder};
-//! use vaultrs::login::AppRoleLogin;
+//! use vaultrs::client::{Client, VaultClient, VaultClientSettingsBuilder};
 //!
 //! // Create a client
 //! let mut client = VaultClient::new(
@@ -53,15 +52,6 @@
 //!         .unwrap()
 //! ).unwrap();
 //!
-//! // A token can be passed at creation or a new one may be acquired through one
-//! // of the login flows.
-//! let role_id = String::from("my-role-id");
-//! let secret_id = String::from("secret");
-//! let login = AppRoleLogin { role_id, secret_id };
-//!
-//! # tokio_test::block_on(async {
-//! client.login("approle", &login).await; // Token is automatically set to client
-//! # })
 //! ```
 //!
 //! ### Secrets
@@ -101,7 +91,7 @@
 //!     &secret,
 //! ).await;
 //!
-//! let secret = kv2::read::<MySecret>(&client, "secret", "mysecret").await.unwrap();
+//! let secret: MySecret = kv2::read(&client, "secret", "mysecret").await.unwrap();
 //! println!("{}", secret.password) // "secret"
 //! # })
 //! ```
@@ -207,7 +197,6 @@ pub mod auth;
 pub mod client;
 pub mod error;
 pub mod kv2;
-pub mod login;
 pub mod pki;
 pub mod ssh;
 pub mod sys;
